S3method(coef,combss)
S3method(predict,combss)
S3method(print,combss)
S3method(summary,combss)
export(combss)
export(combss_cv)
importFrom(stats,aggregate)
importFrom(stats,coef)
importFrom(stats,rnorm)
