#' combss: Best Subset Selection for Generalised Linear Models via Continuous Optimisation
#'
#' Best subset selection in linear, binary logistic, and multinomial logistic
#' regression via a Frank-Wolfe homotopy algorithm. The algorithm reformulates
#' the NP-hard discrete subset selection problem as a continuous optimisation
#' over the hypercube `[0, 1]^p`, scaling to high-dimensional settings with
#' p >> n. Inner ridge solves use \pkg{glmnet}.
#'
#' @keywords internal
#' @importFrom stats aggregate coef rnorm
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL
