\docType{package}
\name{combss-package}
\alias{combss-package}
\title{combss: Best Subset Selection for Generalised Linear Models via Continuous Optimisation}
\description{
Best subset selection in linear, binary logistic, and multinomial logistic
regression via a Frank-Wolfe homotopy algorithm. The algorithm reformulates
the NP-hard discrete subset selection problem as a continuous optimisation
over the hypercube \verb{[0, 1]^p}, scaling to high-dimensional settings with
p >> n. Inner ridge solves use \pkg{glmnet}.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/benoit-liquet/combss}
}

}
\author{
\strong{Maintainer}: Benoit Liquet \email{benoit.liquet@univ-pau.fr} (\href{https://orcid.org/0000-0002-8136-2294}{ORCID})

Authors:
\itemize{
  \item Anant Mathur
  \item Sarat Moka
}

}
\keyword{internal}
